pub struct Enum {
pub description: String,
pub name: Spanned<Identifier<Type>>,
pub variants: Vec<EnumVariant>,
pub base_type: Spanned<BaseType>,
pub size_bits: Option<u32>,
pub generation_style: Option<EnumGenerationStyle>,
pub short_properties_span: Span,
pub properties_span: Option<Span>,
pub span: Span,
}Fields
description: Stringname: Spanned<Identifier<Type>>variants: Vec<EnumVariant>base_type: Spanned<BaseType>size_bits: Option<u32>generation_style: Option<EnumGenerationStyle>short_properties_span: Spanproperties_span: Option<Span>span: SpanSpan of the whole object
Implementations
Sourceimpl Enum
impl Enum
Sourcepub fn iter_variants_with_discriminant(
&self,
) -> impl Iterator<Item = (i128, &EnumVariant)>
pub fn iter_variants_with_discriminant( &self, ) -> impl Iterator<Item = (i128, &EnumVariant)>
Get an iterator over the variants, but with an extra counter to get the specified discriminant for each.
Note: The validity of this is checked in the [passes::enum_values_checked] pass. If this function is run
before that pass, there might be weird results.
Sourcepub fn iter_variants_with_discriminant_mut(
&mut self,
) -> impl Iterator<Item = (i128, &mut EnumVariant)>
pub fn iter_variants_with_discriminant_mut( &mut self, ) -> impl Iterator<Item = (i128, &mut EnumVariant)>
Get an iterator over the variants, but with an extra counter to get the specified discriminant for each.
Note: The validity of this is checked in the [passes::enum_values_checked] pass. If this function is run
before that pass, there might be weird results.