pub struct Extern {
pub description: String,
pub name: Spanned<Identifier<Type>>,
pub base_type: Spanned<BaseType>,
pub supports_infallible: bool,
pub size_bits: Option<Spanned<u64>>,
pub short_properties_span: Span,
pub properties_span: Option<Span>,
pub span: Span,
}Fields
description: Stringname: Spanned<Identifier<Type>>base_type: Spanned<BaseType>From/into what base type can this extern be converted?
supports_infallible: boolIf true, this extern can be converted infallibly too
size_bits: Option<Spanned<u64>>The user-specified size of the max value of the base type that should be expected
short_properties_span: Spanproperties_span: Option<Span>span: SpanSpan of the whole object